@@ -34,10 +34,13 @@ fullVersion =
 data HDevTools
     = Admin
         { socket       :: Maybe FilePath
+        , ghcOpts :: [String]
         , start_server :: Bool
+        , cabalOpts :: [String]
         , noDaemon     :: Bool
         , status       :: Bool
         , stop_server  :: Bool
+        , debug :: Bool
         }
     | Check
         { socket  :: Maybe FilePath
@@ -46,12 +49,14 @@ data HDevTools
         , path    :: Maybe String
         , file    :: String
         , json    :: Bool
+        , debug :: Bool
         }
     | ModuleFile
         { socket  :: Maybe FilePath
         , ghcOpts :: [String]
         , cabalOpts :: [String]
         , module_ :: String
+        , debug :: Bool
         }
     | Info
         { socket     :: Maybe FilePath
@@ -60,6 +65,7 @@ data HDevTools
         , path       :: Maybe String
         , file       :: String
         , identifier :: String
+        , debug :: Bool
         }
     | Type
         { socket  :: Maybe FilePath
@@ -69,6 +75,7 @@ data HDevTools
         , file    :: String
         , line    :: Int
         , col     :: Int
+        , debug :: Bool
         }
     | FindSymbol
         { socket :: Maybe FilePath
@@ -76,16 +83,20 @@ data HDevTools
         , cabalOpts :: [String]
         , symbol :: String
         , files :: [String]
+        , debug :: Bool
         }
     deriving (Show, Data, Typeable)
 
 dummyAdmin :: HDevTools
 dummyAdmin = Admin
     { socket       = Nothing
+    , ghcOpts = []
+    , cabalOpts = []
     , start_server = False
     , noDaemon     = False
     , status       = False
     , stop_server  = False
+    , debug = False
     }
 
 dummyCheck :: HDevTools
@@ -96,6 +107,7 @@ dummyCheck = Check
     , path    = Nothing
     , file    = ""
     , json    = False
+    , debug = False
     }
 
 dummyModuleFile :: HDevTools
@@ -104,6 +116,7 @@ dummyModuleFile = ModuleFile
     , ghcOpts = []
     , cabalOpts = []
     , module_ = ""
+    , debug = False
     }
 
 dummyInfo :: HDevTools
@@ -114,6 +127,7 @@ dummyInfo = Info
     , path       = Nothing
     , file       = ""
     , identifier = ""
+    , debug = False
     }
 
 dummyType :: HDevTools
@@ -125,6 +139,7 @@ dummyType = Type
     , file    = ""
     , line    = 0
     , col     = 0
+    , debug = False
     }
 
 dummyFindSymbol :: HDevTools
@@ -134,15 +149,19 @@ dummyFindSymbol = FindSymbol
     , cabalOpts = []
     , symbol = ""
     , files = []
+    , debug = False
     }
 
 admin :: Annotate Ann
 admin = record dummyAdmin
     [ socket       := def += typFile += help "socket file to use"
+    , ghcOpts  := def += typ "OPTION" += help "ghc options"
+    , cabalOpts := def += typ "OPTION"  += help "cabal options"
     , start_server := def            += help "start server"
     , noDaemon     := def            += help "do not daemonize (only if --start-server)"
     , status       := def            += help "show status of server"
     , stop_server  := def            += help "shutdown the server"
+    , debug    := def                 += help "enable debug output"
     ] += help "Interactions with the server"
 
 check :: Annotate Ann
@@ -153,6 +172,7 @@ check = record dummyCheck
     , path     := def += typFile      += help "path to target file"
     , file     := def += typFile      += argPos 0 += opt ""
     , json     := def                 += help "render output as JSON"
+    , debug    := def                 += help "enable debug output"
     ] += help "Check a haskell source file for errors and warnings"
 
 moduleFile :: Annotate Ann
@@ -161,6 +181,7 @@ moduleFile = record dummyModuleFile
     , ghcOpts  := def += typ "OPTION" += help "ghc options"
     , cabalOpts := def += typ "OPTION"  += help "cabal options"
     , module_  := def += typ "MODULE" += argPos 0
+    , debug    := def                 += help "enable debug output"
     ] += help "Get the haskell source file corresponding to a module name"
 
 info :: Annotate Ann
@@ -171,6 +192,7 @@ info = record dummyInfo
     , path       := def += typFile      += help "path to target file"
     , file       := def += typFile      += argPos 0 += opt ""
     , identifier := def += typ "IDENTIFIER" += argPos 1
+    , debug      := def                 += help "enable debug output"
     ] += help "Get info from GHC about the specified identifier"
 
 type_ :: Annotate Ann
@@ -178,6 +200,7 @@ type_ = record dummyType
     [ socket   := def += typFile += help "socket file to use"
     , ghcOpts  := def += typ "OPTION" += help "ghc options"
     , cabalOpts := def += typ "OPTION"  += help "cabal options"
+    , debug    := def                 += help "enable debug output"
     , path     := def += typFile      += help "path to target file"
     , file     := def += typFile      += argPos 0 += opt ""
     , line     := def += typ "LINE"   += argPos 1
@@ -191,6 +214,7 @@ findSymbol = record dummyFindSymbol
     , cabalOpts := def += typ "OPTION"  += help "cabal options"
     , symbol   := def += typ "SYMBOL" += argPos 0
     , files    := def += typFile += args
+    , debug    := def                 += help "enable debug output"
     ] += help "List the modules where the given symbol could be found"
 
 full :: String -> Annotate Ann
