@@ -7,6 +7,7 @@ module CommandLoop
     , startCommandLoop
     ) where
 
+import Control.Applicative ((<|>))
 import Control.Monad (when)
 import Data.IORef
 import Data.List (find, intercalate)
@@ -20,6 +21,9 @@ import System.Exit (ExitCode(ExitFailure, ExitSuccess))
 import System.FilePath (takeDirectory)
 import qualified ErrUtils
 import qualified Exception (ExceptionMonad)
+#if __GLASGOW_HASKELL__ >= 800
+import qualified DynFlags
+#endif
 import qualified GHC
 import qualified GHC.Paths
 import qualified Outputable
@@ -98,7 +102,7 @@ withWarnings state warningsValue action = do
 
 startCommandLoop :: IORef State -> ClientSend -> IO (Maybe CommandObj) -> Config -> Maybe Command -> IO ()
 startCommandLoop state clientSend getNextCommand initialConfig mbInitialCommand = do
-    continue <- GHC.runGhc (Just GHC.Paths.libdir) $ do
+    continue <- GHC.runGhc ghcLibDir $ do
         configResult <- configSession state clientSend initialConfig
         case configResult of
           Left e -> do
@@ -116,7 +120,10 @@ startCommandLoop state clientSend getNextCommand initialConfig mbInitialCommand
             -- Exit
             return ()
         Just (cmd, config) -> startCommandLoop state clientSend getNextCommand config (Just cmd)
-    where
+  where
+    ghcLibDir = stackGhcLibDir <$> configStack initialConfig
+                <|> Just GHC.Paths.libdir
+
     processNextCommand :: Bool -> GHC.Ghc (Maybe CommandObj)
     processNextCommand forceReconfig = do
         mbNextCmd <- liftIO getNextCommand
@@ -255,7 +262,14 @@ runCommand state clientSend (CmdFindSymbol symbol files) = do
 
 
 
-#if __GLASGOW_HASKELL__ >= 706
+#if __GLASGOW_HASKELL__ >= 800
+logAction :: IORef State -> ClientSend -> GHC.DynFlags -> DynFlags.WarnReason -> GHC.Severity -> GHC.SrcSpan -> Outputable.PprStyle -> ErrUtils.MsgDoc -> IO ()
+logAction state clientSend dflags _ severity srcspan style msg =
+    let out = Outputable.renderWithStyle dflags fullMsg style
+        _ = severity
+    in logActionSend state clientSend severity out
+    where fullMsg = ErrUtils.mkLocMessage severity srcspan msg
+#elif __GLASGOW_HASKELL__ >= 706
 logAction :: IORef State -> ClientSend -> GHC.DynFlags -> GHC.Severity -> GHC.SrcSpan -> Outputable.PprStyle -> ErrUtils.MsgDoc -> IO ()
 logAction state clientSend dflags severity srcspan style msg =
     let out = Outputable.renderWithStyle dflags fullMsg style
