@@ -176,7 +176,10 @@ pretty dflags =
 pretty :: GHC.Type -> String
 pretty =
 #endif
-#if __GLASGOW_HASKELL__ >= 708
+#if __GLASGOW_HASKELL__ >= 800
+    Pretty.renderStyle
+      Pretty.style{ Pretty.lineLength = 0, Pretty.mode = Pretty.OneLineMode }
+#elif __GLASGOW_HASKELL__ >= 708
     Pretty.showDoc Pretty.OneLineMode 0
 #else
     Pretty.showDocWith Pretty.OneLineMode
